* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Diagrams](https://help.sap.com/docs/leanix/ea/diagrams)
  * Creating Diagrams and Adding Basic Elements
